@@ -1,5 +1,5 @@
 package Gherkin::Dialect;
-$Gherkin::Dialect::VERSION = '32.1.2';
+$Gherkin::Dialect::VERSION = '32.2.0';
 use strict;
 use warnings;
 
@@ -96,7 +96,8 @@ one to be used for keyword translation lookup. Out of the box, Gherkin comes
 with actual translations, such as C<Afrikaans> as well as 'slang-like'
 translations such as "Pirate English".
 
-This module is used by the L<token matcher|Gherkin::TokenMatcher> to identify
+This module is used by the L<token matcher|Gherkin::TokenMatcher> and
+the L<Markdown token matcher|Gherkin::MarkdownTokenMatcher> to identify
 the type of token (input line) passed to the scanner.
 
 =head1 METHODS
